@@ -17,8 +17,7 @@ class UType:
     Test Helper used to test and format data.
 
     Contain only static methods.
-    ToDo:
-        - Improve DocStrings
+
     """
 
     @staticmethod
@@ -236,7 +235,7 @@ class UType:
         """
         Check if the given value is a valid dict key.
 
-        TODO: This method must be in utils re
+
         :param value: dict key to test
         :param not_null: if True, input value can't be null, False by default
         :param mini: Min value
@@ -260,7 +259,7 @@ class UType:
         """
         Check if the given value is a valid string dict key.
 
-        TODO: This method must be in utils re
+
         :param value: dict key to test
         :param mini: Min value length
         :param maxi: Max value length
@@ -534,7 +533,7 @@ class UType:
         """
         Convert a string or an int to a boolean.
 
-        Todo: Change method name.
+
         :param s: Used to pass the value to be converted.
         :param default: Used to set a default value for the parameter.
         :return:
